@@ -1,6 +1,7 @@
 from .client import Client
 from .datasource import Datasource, Record
-from .pipe import Pipe, PipeError, PipeJsonData, PipeJsonResponse, PipeMetadata
+from .pipe import Pipe, PipeError, PipeJsonData, PipeJsonResponse, PipeMetadata, PipePageIterator
+from .query import OutputFormat, QueryError, SqlQuery
 
 __all__ = [
     "Client",
@@ -12,4 +13,7 @@ __all__ = [
     "PipeJsonData",
     "PipeJsonResponse",
     "PipePageIterator",
+    "SqlQuery",
+    "QueryError",
+    "OutputFormat",
 ]
